package eu.cedarsoft.wicket.navigation;

import org.apache.wicket.markup.html.WebComponent;
import org.apache.wicket.markup.html.WebMarkupContainer;
import org.apache.wicket.markup.repeater.Item;
import org.apache.wicket.markup.repeater.data.DataView;
import org.apache.wicket.markup.repeater.data.IDataProvider;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;

/**
 * A view for links. The given {@link IDataProvider} must provide {@link LinkProvider}s
 */
public class LinksDataView extends DataView {
  @NotNull
  @NonNls
  public static final String ID = "links";

  @NotNull
  @NonNls
  static final String ID_LINK = "link";
  @NotNull
  @NonNls
  static final String ID_LABEL = "label";

  public LinksDataView( @NotNull IDataProvider /*<LinkProvider>*/ dataProvider ) {
    super( ID, dataProvider );
  }

  @Override
  protected void populateItem( @NotNull Item item ) {
    LinkProvider linkProvider = ( LinkProvider ) item.getModelObject();

    WebMarkupContainer link = linkProvider.createLink( ID_LINK );
    if ( !ID_LINK.equals( link.getId() ) ) {
      throw new IllegalStateException( "Link must have the ID set to " + ID_LINK );
    }
    WebComponent label = linkProvider.createLabel( ID_LABEL );
    if ( !ID_LABEL.equals( label.getId() ) ) {
      throw new IllegalStateException( "Label must have the ID set to " + ID_LABEL );
    }

    link.add( label );
    item.add( link );
  }
}
